@@ -81,7 +81,7 @@ override('finalize', sub {
         push(@{ $self->{COLORS} }, $clicker->color_allocator->next);
     }
 
-    my @keys = @{ $dses->[0]->get_series(0)->keys };
+    my @keys = $dses->[0]->get_all_series_keys;
 
     # Iterate over each key...
     for (my $i = 0; $i < scalar(@keys); $i++) {
@@ -98,7 +98,12 @@ override('finalize', sub {
 
         my $val = 0;
         for my $j (0 .. $#values) {
-            $val += $values[$j];
+            my $sval = $values[$j];
+            if(defined($sval)) {
+                next if $sval == $range->baseline; # no reason to draw anything if no value
+                $val += $sval;
+            }
+
             my $y = $range->mark($height, $val);
             next unless defined($y);
 
